# MilkViz

[![Documentation Status](https://img.shields.io/readthedocs/milkviz?logo=readthedocs&logoColor=white&style=flat-square)](https://milkviz.readthedocs.io/en/latest?badge=latest)
![Build&Test](https://img.shields.io/github/workflow/status/Mr-Milk/milkviz/Build?style=flat-square&logo=github)
![pypi version](https://img.shields.io/pypi/v/milkviz?color=blue&logo=python&logoColor=white&style=flat-square)

Mr-Milk's own visualization library. 
Some commonly used visualizations in my own research.
But not available out there.

[Gallery](https://milkviz.readthedocs.io/en/latest/gallery_examples/index.html)

--------------------
Copyright © 2021, Mr-Milk
